@@ -26,11 +26,11 @@ from pathlib import Path
 import time
 from tkinter import messagebox
 import tkinter.font as font 
-
 class App1:
     def __init__(self,parent,media,window_title,video_source=0):
         self.window = Toplevel(parent)
         self.window.title(window_title)
+        self.window.resizable(False,False)
         self.video_source = video_source
         self.media = media
         self.vid = MyVideoCapture(self.media,video_source)
@@ -46,7 +46,7 @@ class App1:
         del self.vid
         cv2.destroyAllWindows()
 
-        #uncomment these 4 lines for a message window
+        #uncomment these 4 lines for a message window and comment the above 3 lines
         # if messagebox.askokcancel("Quit", "Do you want to quit?"):
         #     self.window.destroy()
         #     del self.vid
@@ -108,7 +108,7 @@ class MyVideoCapture:
         self.vid = cv2.VideoCapture(video_source)
         self.media = media
         if not self.vid.isOpened():
-            raise ValueError("unable to open video source",video_source)
+            raise ValueError("Unable to open video source",video_source)
 
         self.WIDTH = 640
         self.HEIGHT = 480
@@ -220,7 +220,6 @@ class MenuBar(Menu,tk.Button,tk.Scale):
         file.add_command(label="Exit",command=self.close)
 
         self.add_cascade(label="File",menu=file)
-
         self.width = root.winfo_screenwidth()
         self.height = root.winfo_screenheight()
         self.frame = tk.Frame(self.parent,width=self.width,height=self.height,bg='black')
@@ -251,13 +250,15 @@ class MenuBar(Menu,tk.Button,tk.Scale):
             title = "Choose a video file",
             filetypes = (("all files","*.*"),
                 ("mp4 files", "*.mp4"),
-                ("mov files", "*.mov")))
+                ("mov files", "*.mov"),
+                ("mkv files","*.mkv")))
 
         self.Play(video)
 
     def stop_file(self):
         if vlc.libvlc_media_player_is_playing(self.media):
             self.media.stop()
+            # del self.media
 
     def Play(self,video):
         self.media = vlc.MediaPlayer(video)
@@ -265,6 +266,7 @@ class MenuBar(Menu,tk.Button,tk.Scale):
             self.media.set_xwindow(self.parent.winfo_id())
         if platform.system() == 'Windows':
             self.media.set_hwnd(self.frame.winfo_id())
+        #if video already playing stop it add code here
         self.media.play()
         self.volume_scale.set(vlc.libvlc_audio_get_volume(self.media))
         
@@ -310,7 +312,26 @@ class MenuBar(Menu,tk.Button,tk.Scale):
 
         #testing
 
-        App1(self.parent,self.media,"Gesture Window")
+        #if gesture window is open, button color should be green
+        #if gesture window is closed, revert back to red
+        # gesture_button_count = 1
+        # if gesture_button_count is odd then color is red
+        # else button color is green
+        # try: 
+        #     if gesture_button_count%2!=0:
+        #         self.gesture_button.configure(bg ='green')
+        #     else:
+        #         self.gesture_button.configure(bg ='red')
+
+        try:
+            # if self.gesture_button.cget('bg') == 'red':
+            #     self.gesture_button.configure(bg ='green')
+            # elif self.gesture_button.cget('bg') =='green':
+            #     self.gesture_button.configure(bg='red')
+
+            App1(self.parent,self.media,"Gesture Window")
+        except AttributeError:
+            pass
         
 
     def close(self):
@@ -363,6 +384,9 @@ def main():
     # frame = FrameBox(app)
     file_menu = MenuBar(app)
     app.config(menu=file_menu)
+    #testing
+    # if 'normal' == app.state():
+    #     print("running")
     # app.on_closing()
     app.mainloop()
 
